==> jc-tke-client-1.1.276-sources.jar: com/xforceplus/jctke/controller/AdvanceChargeInterfaceFeignApi.java <==
package com.xforceplus.jctke.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-10-10
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jctke.entity.AdvanceChargeInterface;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface AdvanceChargeInterfaceFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/advanceChargeInterface/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param advanceChargeInterface ${table.comment}
   * @return R
   */
  @PostMapping("/advanceChargeInterface/add")
  public R save(@RequestBody AdvanceChargeInterface advanceChargeInterface);

  /**
   * 修改${table.comment}
   * @param advanceChargeInterface ${table.comment}
   * @return R
   */
  @PostMapping("/advanceChargeInterface/update")
  public R updateById(@RequestBody AdvanceChargeInterface advanceChargeInterface);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/advanceChargeInterface/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-tke-client-1.1.387-sources.jar: com/xforceplus/jctke/controller/AdvanceChargeInterfaceFeignApi.java <==
package com.xforceplus.jctke.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-12-02
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.jctke.entity.AdvanceChargeInterface;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface AdvanceChargeInterfaceFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/advanceChargeInterface/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param advanceChargeInterface ${table.comment}
   * @return R
   */
  @PostMapping("/advanceChargeInterface/add")
  public R save(@RequestBody AdvanceChargeInterface advanceChargeInterface);

  /**
   * 修改${table.comment}
   * @param advanceChargeInterface ${table.comment}
   * @return R
   */
  @PostMapping("/advanceChargeInterface/update")
  public R updateById(@RequestBody AdvanceChargeInterface advanceChargeInterface);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/advanceChargeInterface/del/{id}" )
  public R removeById(@PathVariable Long id);

}
